==> thousandeyes_sdk_alerts-2.5.0.tar.gz: thousandeyes_sdk_alerts-2.5.0/docs/AlertSimpleTest.md <==
# AlertSimpleTest

Each test includes additional fields depending on its `type`. Refer `/tests/{type}` endpoint to know the set of fields returned by a given `type`.

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**interval** | [**TestInterval**](TestInterval.md) |  | [optional] 
**alerts_enabled** | **bool** | Indicates if alerts are enabled. | [optional] 
**enabled** | **bool** | Test is enabled. | [optional] [default to True]
**created_by** | **str** | User that created the test. | [optional] [readonly] 
**created_date** | **datetime** | UTC created date (ISO date-time format). | [optional] [readonly] 
**description** | **str** | A description of the test. | [optional] 
**live_share** | **bool** | Indicates if the test is shared with the account group. | [optional] [readonly] 
**modified_by** | **str** | User that modified the test. | [optional] [readonly] 
**modified_date** | **datetime** | UTC last modification date (ISO date-time format). | [optional] [readonly] 
**saved_event** | **bool** | Indicates if the test is a saved event. | [optional] [readonly] 
**test_id** | **str** | Each test is assigned an unique ID; this is used to access test information and results from other endpoints. | [optional] [readonly] 
**test_name** | **str** | The name of the test. Test name must be unique. | [optional] 
**type** | [**AlertTestType**](AlertTestType.md) |  | [optional] 
**links** | [**TestLinks**](TestLinks.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.alerts.models.alert_simple_test import AlertSimpleTest

# TODO update the JSON string below
json = "{}"
# create an instance of AlertSimpleTest from a JSON string
alert_simple_test_instance = AlertSimpleTest.from_json(json)
# print the JSON string representation of the object
print(AlertSimpleTest.to_json())

# convert the object into a dict
alert_simple_test_dict = alert_simple_test_instance.to_dict()
# create an instance of AlertSimpleTest from a dict
alert_simple_test_from_dict = AlertSimpleTest.from_dict(alert_simple_test_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> thousandeyes_sdk_alerts-2.11.0.tar.gz: thousandeyes_sdk_alerts-2.11.0/docs/AlertSimpleTest.md <==
# AlertSimpleTest

Each test includes additional fields depending on its `type`. Refer `/tests/{type}` endpoint to know the set of fields returned by a given `type`.

## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**interval** | [**TestInterval**](TestInterval.md) |  | [optional] 
**alerts_enabled** | **bool** | Indicates if alerts are enabled. | [optional] 
**enabled** | **bool** | Test is enabled. | [optional] [default to True]
**created_by** | **str** | User that created the test. | [optional] [readonly] 
**created_date** | **datetime** | UTC created date (ISO date-time format). | [optional] [readonly] 
**description** | **str** | A description of the test. | [optional] 
**live_share** | **bool** | Indicates if the test is shared with the account group. | [optional] [readonly] 
**modified_by** | **str** | User that modified the test. | [optional] [readonly] 
**modified_date** | **datetime** | UTC last modification date (ISO date-time format). | [optional] [readonly] 
**saved_event** | **bool** | Indicates if the test is a saved event. **Note**: **Saved Events** are now called **Private Snapshots** in the user interface. This change does not affect API. | [optional] [readonly] 
**test_id** | **str** | Each test is assigned an unique ID; this is used to access test information and results from other endpoints. | [optional] [readonly] 
**test_name** | **str** | The name of the test. Test name must be unique. | [optional] 
**type** | [**AlertTestType**](AlertTestType.md) |  | [optional] 
**links** | [**TestLinks**](TestLinks.md) |  | [optional] 

## Example

```python
from thousandeyes_sdk.alerts.models.alert_simple_test import AlertSimpleTest

# TODO update the JSON string below
json = "{}"
# create an instance of AlertSimpleTest from a JSON string
alert_simple_test_instance = AlertSimpleTest.from_json(json)
# print the JSON string representation of the object
print(AlertSimpleTest.to_json())

# convert the object into a dict
alert_simple_test_dict = alert_simple_test_instance.to_dict()
# create an instance of AlertSimpleTest from a dict
alert_simple_test_from_dict = AlertSimpleTest.from_dict(alert_simple_test_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)
